@@ -353,38 +353,7 @@ get_monitor_height ()
 static gchar *
 get_background_filename (void)
 {
-  gint widths[] =  { 2560, 1920, 1680, 1440, 1280, 1024, 800 };
-  gint heights[] = { 1600, 1200, 1050, 900,  1024, 768,  600 };
-  gint width, height;
-  gint i;
-  gint last_good = 0;
-  gchar *ret;
-
-  width = get_monitor_width ();
-  height = get_monitor_height ();
-
-  g_message ("get_background_filename(): looking for appropriate resolution...");
-  for (i = 0; i < (sizeof (widths) / sizeof (gint)); i++)
-    {
-      if (widths[i] > width && heights[i] && height)
-        {
-          g_message (" ** %dx%d will work.", widths[i], heights[i]);
-          last_good = i;
-        }
-      else
-        {
-          g_message (" ** %dx%d is too small, using last good size.", widths[i], heights[i]);
-          break;
-        }
-    }
-
-  g_message (" ** Found a resolution: %dx%d", widths[last_good], heights[last_good]);
-
-  ret = g_strdup_printf (DATADIR "/images/xsplash/bg_%dx%d.jpg", widths[last_good], heights[last_good]);
-
-  g_message (" ** filename: %s", ret);
-
-  return ret;
+  return g_strdup (DATADIR "/images/xsplash/bg_2560x1600.jpg");
 }
 
 static const gchar *
